@@ -14,7 +14,7 @@
 # with this program; if not, write to the Free Software Foundation,
 # Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
 
-package Debian::Debhelper::Buildsystem::octave;
+package Debian::Debhelper::Buildsystem::octave; ## no critic
 
 use strict;
 use warnings;
